@@ -218,6 +218,11 @@ impl LuaState {
 		(LUA_SHARED.lua_pushvalue)(*self, LUA_GLOBALSINDEX)
 	}
 
+	#[inline(always)]
+	pub unsafe fn push_registry(&self) {
+		(LUA_SHARED.lua_pushvalue)(*self, LUA_REGISTRYINDEX)
+	}
+
 	#[inline(always)]
 	pub unsafe fn push_string(&self, data: &str) {
 		(LUA_SHARED.lua_pushlstring)(*self, data.as_ptr() as LuaString, data.len())
@@ -325,6 +330,16 @@ impl LuaState {
 		(LUA_SHARED.lua_getmetatable)(*self, index)
 	}
 
+	#[inline(always)]
+	pub unsafe fn check_table(&self, arg: i32) {
+		(LUA_SHARED.lual_checktype)(*self, arg, LUA_TTABLE)
+	}
+
+	#[inline(always)]
+	pub unsafe fn check_function(&self, arg: i32) {
+		(LUA_SHARED.lual_checktype)(*self, arg, LUA_TFUNCTION)
+	}
+
 	#[inline(always)]
 	pub unsafe fn check_integer(&self, arg: i32) -> LuaInt {
 		(LUA_SHARED.lual_checkinteger)(*self, arg)
@@ -386,6 +401,47 @@ impl LuaState {
 		(LUA_SHARED.lua_topointer)(*self, index)
 	}
 
+	#[inline(always)]
+	pub unsafe fn to_userdata(&self, index: i32) -> *mut c_void {
+		(LUA_SHARED.lua_touserdata)(*self, index)
+	}
+
+	/// Creates a new table in the registry with the given `name` as the key if it doesn't already exist, and pushes it onto the stack.
+	///
+	/// Returns if the metatable was already present in the registry.
+	pub unsafe fn new_metatable(&self, name: LuaString) -> bool {
+		(LUA_SHARED.lual_newmetatable)(*self, name) == 0
+	}
+
+	pub unsafe fn new_userdata<T: Sized>(&self, data: T, metatable: Option<i32>) -> *mut T {
+		let has_metatable = if std::mem::needs_drop::<T>() {
+			if let Some(metatable) = metatable {
+				self.push_value(metatable);
+			} else {
+				self.new_table();
+			}
+			self.push_function(crate::userdata::__gc::<T>);
+			self.set_field(-2, crate::lua_string!("__gc"));
+			true
+		} else if let Some(metatable) = metatable {
+			self.push_value(metatable);
+			true
+		} else {
+			false
+		};
+
+		let ptr = (LUA_SHARED.lua_newuserdata)(*self, std::mem::size_of::<T>()) as *mut T;
+
+		if has_metatable {
+			self.push_value(-2);
+			self.set_metatable(-2);
+			self.remove(-2);
+		}
+
+		ptr.write(data);
+		ptr
+	}
+
 	pub unsafe fn error<S: AsRef<str>>(&self, msg: S) -> ! {
 		self.push_string(msg.as_ref());
 		(LUA_SHARED.lua_error)(*self);
